# NanDealer 
This library takes your dataframe with Nan values and performs the functions to deal with nan values, and then returns the dataframe with only numerical columns. For input it can take data frame with categorical columns as well, and in output only numerical columns will be returned.

## Installation
pip install NanDealer

## How to use it?
###Step 1: Import the nanDealer class.
###Step 2: Read any dataframe.
###step 3: Pass your dataframe to the Nan values handling methods of nanDealer class.
###step 4: You will receive a dataframe with Nan values converted according to the method used and the dataframe will be free from all categorical columns.
###Step 5: If your dataframe does not have any Nan values, then no modification will happen in your dataframe apart from removal of categorical data.

####You can see the example of that in Test.py class by navigating to github.

## License
MIT License

